@@ -44,7 +44,7 @@ from robotcode.language_server.robotframework.utils.ast_utils import (
 from robotcode.language_server.robotframework.utils.markdownformatter import (
     MarkDownFormatter,
 )
-from robotcode.language_server.robotframework.utils.match import normalize
+from robotcode.language_server.robotframework.utils.match import normalize, normalize_namespace
 from robotcode.language_server.robotframework.utils.version import get_robot_version
 
 from .entities import (
@@ -150,16 +150,17 @@ def is_embedded_keyword(name: str) -> bool:
 
 
 class KeywordMatcher:
-    def __init__(self, name: str, can_have_embedded: bool = True) -> None:
+    def __init__(self, name: str, can_have_embedded: bool = True, is_namespace: bool = False) -> None:
         self.name = name
-        self._can_have_embedded = can_have_embedded
+        self._can_have_embedded = can_have_embedded and not is_namespace
+        self._is_namespace = is_namespace
         self._normalized_name: Optional[str] = None
         self._embedded_arguments: Any = None
 
     @property
     def normalized_name(self) -> str:
         if self._normalized_name is None:
-            self._normalized_name = str(normalize(self.name))
+            self._normalized_name = str(normalize_namespace(self.name) if self._is_namespace else normalize(self.name))
 
         return self._normalized_name
 
@@ -184,6 +185,9 @@ class KeywordMatcher:
 
     def __eq__(self, o: Any) -> bool:
         if isinstance(o, KeywordMatcher):
+            if self._is_namespace != o._is_namespace:
+                return False
+
             if not self.embedded_arguments:
                 return self.normalized_name == o.normalized_name
 
@@ -198,14 +202,14 @@ class KeywordMatcher:
 
             return self.embedded_arguments.name.match(o) is not None
 
-        return self.normalized_name == str(normalize(o))
+        return self.normalized_name == str(normalize_namespace(o) if self._is_namespace else normalize(o))
 
     @single_call
     def __hash__(self) -> int:
         return hash(
             (self.embedded_arguments.name, tuple(self.embedded_arguments.args))
             if self.embedded_arguments
-            else (self.normalized_name,)
+            else (self.normalized_name, self._is_namespace),
         )
 
     def __str__(self) -> str:
@@ -472,7 +476,11 @@ class ArgumentSpec:
             )
             return cast(Tuple[List[Any], List[Tuple[str, Any]]], resolver.resolve(arguments, variables))
 
-        positional, named = NamedArgumentResolver(self.__robot_arguments).resolve(arguments, variables)
+        class MyNamedArgumentResolver(NamedArgumentResolver):
+            def _raise_positional_after_named(self) -> None:
+                pass
+
+        positional, named = MyNamedArgumentResolver(self.__robot_arguments).resolve(arguments, variables)
         positional, named = VariableReplacer(resolve_variables_until).replace(positional, named, variables)
         positional, named = DictToKwargs(self.__robot_arguments, dict_to_kwargs).handle(positional, named)
         return positional, named
@@ -658,10 +666,13 @@ class KeywordDoc(SourceEntity):
                 elif a.kind == KeywordArgumentKind.POSITIONAL_ONLY:
                     prefix = "⟶"
 
+                def escape_pipe(s: str) -> str:
+                    return s.replace("|", "\\|")
+
                 result += (
                     f"\n| `{prefix}{a.name!s}`"
-                    f'{": " if a.types else " "}'
-                    f"| {escaped_pipe.join(f'`{s}`' for s in a.types) if a.types else ''} "
+                    f'| {": " if a.types else " "}'
+                    f"{escaped_pipe.join(f'`{escape_pipe(s)}`' for s in a.types) if a.types else ''} "
                     f"| {'=' if a.default_value is not None else ''} "
                     f"| {f'`{a.default_value!s}`' if a.default_value else ''} |"
                 )
@@ -1623,7 +1634,6 @@ def get_library_doc(
                     raise
                 except BaseException:
                     lib = None
-                    pass
 
         real_source = lib.source if lib is not None else source
 
@@ -1925,28 +1935,10 @@ def get_variables_doc(
                 if importer.is_dynamic():
                     get_variables = getattr(libcode, "get_variables", None) or getattr(libcode, "getVariables", None)
 
-            # TODO: add type information of the value including dict key names and member names
-            vars: List[ImportedVariableDefinition] = [
-                ImportedVariableDefinition(
-                    1,
-                    0,
-                    1,
-                    0,
-                    source or (module_spec.origin if module_spec is not None else None) or "",
-                    name,
-                    None,
-                    value=NativeValue(value) if value is None or isinstance(value, (int, float, bool, str)) else None,
-                    has_value=value is None or isinstance(value, (int, float, bool, str)),
-                    value_is_native=value is None or isinstance(value, (int, float, bool, str)),
-                )
-                for name, value in importer.import_variables(import_name, args)
-            ]
-
             libdoc = VariablesDoc(
                 name=stem,
                 source=source or module_spec.origin if module_spec is not None else import_name,
                 module_spec=module_spec,
-                variables=vars,
                 stdout=std_capturer.getvalue(),
                 python_path=sys.path,
             )
@@ -2023,6 +2015,39 @@ def get_variables_doc(
                                 ]
                             ]
                         )
+            try:
+                # TODO: add type information of the value including dict key names and member names
+                libdoc.variables = [
+                    ImportedVariableDefinition(
+                        1,
+                        0,
+                        1,
+                        0,
+                        source or (module_spec.origin if module_spec is not None else None) or "",
+                        name,
+                        None,
+                        value=NativeValue(value)
+                        if value is None or isinstance(value, (int, float, bool, str))
+                        else None,
+                        has_value=value is None or isinstance(value, (int, float, bool, str)),
+                        value_is_native=value is None or isinstance(value, (int, float, bool, str)),
+                    )
+                    for name, value in importer.import_variables(import_name, args)
+                ]
+            except (SystemExit, KeyboardInterrupt):
+                raise
+            except BaseException as e:
+                libdoc.errors = [
+                    error_from_exception(
+                        e,
+                        source or module_spec.origin
+                        if module_spec is not None and module_spec.origin
+                        else import_name
+                        if is_variables_by_path(import_name)
+                        else None,
+                        1 if source is not None or module_spec is not None and module_spec.origin is not None else None,
+                    )
+                ]
 
             return libdoc
     except (SystemExit, KeyboardInterrupt, IgnoreEasterEggLibraryWarning):
